@@ -1,6 +1,6 @@
 package Mail::DMARC::Report;
 {
-  $Mail::DMARC::Report::VERSION = '0.20130514';
+  $Mail::DMARC::Report::VERSION = '0.20130515';
 }
 use strict;
 use warnings;
@@ -13,6 +13,7 @@ use parent 'Mail::DMARC::Base';
 require Mail::DMARC::Report::Send;
 require Mail::DMARC::Report::Store;
 require Mail::DMARC::Report::Receive;
+require Mail::DMARC::Report::URI;
 require Mail::DMARC::Report::View;
 
 sub dmarc {
@@ -38,6 +39,12 @@ sub store {
     return $self->{store} = Mail::DMARC::Report::Store->new();
 };
 
+sub uri {
+    my $self = shift;
+    return $self->{uri} if ref $self->{uri};
+    return $self->{uri} = Mail::DMARC::Report::URI->new();
+};
+
 sub view {
     my $self = shift;
     return $self->{view} if ref $self->{view};
@@ -205,7 +212,7 @@ Mail::DMARC::Report - A DMARC report object
 
 =head1 VERSION
 
-version 0.20130514
+version 0.20130515
 
 =head1 DESCRIPTION
 
